@@ -326,7 +326,6 @@ var searchData=
   ['pathjointype',['PathJoinType',['../namespacecom_1_1sun_1_1star_1_1rendering_1_1PathJoinType.html',1,'com::sun::star::rendering']]],
   ['placeholdertype',['PlaceholderType',['../namespacecom_1_1sun_1_1star_1_1text_1_1PlaceholderType.html',1,'com::sun::star::text']]],
   ['plugin',['plugin',['../namespacecom_1_1sun_1_1star_1_1plugin.html',1,'com::sun::star']]],
-  ['pluginmode',['PluginMode',['../namespacecom_1_1sun_1_1star_1_1plugin_1_1PluginMode.html',1,'com::sun::star::plugin']]],
   ['popupmenudirection',['PopupMenuDirection',['../namespacecom_1_1sun_1_1star_1_1awt_1_1PopupMenuDirection.html',1,'com::sun::star::awt']]],
   ['positionandspacemode',['PositionAndSpaceMode',['../namespacecom_1_1sun_1_1star_1_1text_1_1PositionAndSpaceMode.html',1,'com::sun::star::text']]],
   ['positionlayoutdir',['PositionLayoutDir',['../namespacecom_1_1sun_1_1star_1_1text_1_1PositionLayoutDir.html',1,'com::sun::star::text']]],
@@ -379,6 +378,7 @@ var searchData=
   ['sdb',['sdb',['../namespacecom_1_1sun_1_1star_1_1sdb.html',1,'com::sun::star']]],
   ['sdbc',['sdbc',['../namespacecom_1_1sun_1_1star_1_1sdbc.html',1,'com::sun::star']]],
   ['sdbcx',['sdbcx',['../namespacecom_1_1sun_1_1star_1_1sdbcx.html',1,'com::sun::star']]],
+  ['searchalgorithms2',['SearchAlgorithms2',['../namespacecom_1_1sun_1_1star_1_1util_1_1SearchAlgorithms2.html',1,'com::sun::star::util']]],
   ['searchflags',['SearchFlags',['../namespacecom_1_1sun_1_1star_1_1util_1_1SearchFlags.html',1,'com::sun::star::util']]],
   ['sectionpagebreak',['SectionPageBreak',['../namespacecom_1_1sun_1_1star_1_1report_1_1SectionPageBreak.html',1,'com::sun::star::report']]],
   ['security',['security',['../namespacecom_1_1sun_1_1star_1_1security.html',1,'com::sun::star']]],
@@ -438,8 +438,8 @@ var searchData=
   ['tree',['tree',['../namespacecom_1_1sun_1_1star_1_1awt_1_1tree.html',1,'com::sun::star::awt']]],
   ['type',['Type',['../namespacecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Type.html',1,'com::sun::star::text::textfield']]],
   ['ucb',['ucb',['../namespacecom_1_1sun_1_1star_1_1ucb.html',1,'com::sun::star']]],
-  ['ui',['ui',['../namespacecom_1_1sun_1_1star_1_1deployment_1_1ui.html',1,'com::sun::star::deployment']]],
   ['ui',['ui',['../namespacecom_1_1sun_1_1star_1_1ui.html',1,'com::sun::star']]],
+  ['ui',['ui',['../namespacecom_1_1sun_1_1star_1_1deployment_1_1ui.html',1,'com::sun::star::deployment']]],
   ['uielementtype',['UIElementType',['../namespacecom_1_1sun_1_1star_1_1ui_1_1UIElementType.html',1,'com::sun::star::ui']]],
   ['unicodetype',['UnicodeType',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1UnicodeType.html',1,'com::sun::star::i18n']]],
   ['uno',['uno',['../namespacecom_1_1sun_1_1star_1_1uno.html',1,'com::sun::star']]],
@@ -471,8 +471,8 @@ var searchData=
   ['wrapper',['wrapper',['../namespacecom_1_1sun_1_1star_1_1xml_1_1wrapper.html',1,'com::sun::star::xml']]],
   ['writingmode2',['WritingMode2',['../namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html',1,'com::sun::star::text']]],
   ['xforms',['xforms',['../namespacecom_1_1sun_1_1star_1_1xforms.html',1,'com::sun::star']]],
-  ['xml',['xml',['../namespacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1xml.html',1,'com::sun::star::configuration::backend']]],
   ['xml',['xml',['../namespacecom_1_1sun_1_1star_1_1xml.html',1,'com::sun::star']]],
+  ['xml',['xml',['../namespacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1xml.html',1,'com::sun::star::configuration::backend']]],
   ['xpath',['xpath',['../namespacecom_1_1sun_1_1star_1_1xml_1_1xpath.html',1,'com::sun::star::xml']]],
   ['xsd',['xsd',['../namespacecom_1_1sun_1_1star_1_1xsd.html',1,'com::sun::star']]],
   ['xslt',['xslt',['../namespacecom_1_1sun_1_1star_1_1xml_1_1xslt.html',1,'com::sun::star::xml']]],
